@@ -1,5 +1,6 @@
 from datetime import datetime
 
+from django.utils.translation import ugettext_lazy as _
 from django.template import Library, TemplateSyntaxError
 
 from tendenci.core.base.template_tags import ListNode, parse_tag_kwargs
@@ -83,11 +84,11 @@ def list_articles(parser, token):
 
     if len(bits) < 3:
         message = "'%s' tag requires more than 3" % bits[0]
-        raise TemplateSyntaxError(message)
+        raise TemplateSyntaxError(_(message))
 
     if bits[1] != "as":
         message = "'%s' second argument must be 'as" % bits[0]
-        raise TemplateSyntaxError(message)
+        raise TemplateSyntaxError(_(message))
 
     kwargs = parse_tag_kwargs(bits)
 
