@@ -1,5 +1,7 @@
 from django import forms
 from django.contrib.auth.models import User
+from django.utils.translation import ugettext_lazy as _
+
 from tastypie.models import ApiKey
 from tendenci.core.perms.models import TendenciBaseModel
 
@@ -15,7 +17,7 @@ class ApiKeyForm(forms.ModelForm):
     def clean_user(self):
         user = self.cleaned_data['user']
         if not user.profile.is_superuser:
-            raise forms.ValidationError('This user is not a superuser.')
+            raise forms.ValidationError(_('This user is not a superuser.'))
         return user
 
 class TendenciForm(forms.ModelForm):
